# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.voice import Voice

ListVoicesListVoicesGetResponseItem = typing.Union[typing.Dict[str, typing.Any], Voice]
