# This file was auto-generated by Fern from our API Definition.

import typing

CreateStreamTtsRequestPayloadSpeechModel = typing.Union[
    typing.Literal["auto", "mars-8", "mars-8-flash", "mars-8-instruct", "mars-7", "mars-6"], typing.Any
]
