# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .demixing_option import DemixingOption
from .revoicing_option import RevoicingOption
from .segmenting_option import SegmentingOption
from .transcribing_option import TranscribingOption
from .translating_option import TranslatingOption


class ConfigStreamPipeline(UniversalBaseModel):
    demixing: typing.Optional[DemixingOption] = None
    segmenting: typing.Optional[SegmentingOption] = None
    transcribing: typing.Optional[TranscribingOption] = None
    translating: typing.Optional[TranslatingOption] = None
    revoicing: typing.Optional[RevoicingOption] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
