# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .create_stream_tts_request_payload_language import CreateStreamTtsRequestPayloadLanguage
    from .create_stream_tts_request_payload_speech_model import CreateStreamTtsRequestPayloadSpeechModel
    from .get_tts_results_tts_results_post_response_value import GetTtsResultsTtsResultsPostResponseValue
    from .get_tts_run_info_tts_result_run_id_get_response import GetTtsRunInfoTtsResultRunIdGetResponse
_dynamic_imports: typing.Dict[str, str] = {
    "CreateStreamTtsRequestPayloadLanguage": ".create_stream_tts_request_payload_language",
    "CreateStreamTtsRequestPayloadSpeechModel": ".create_stream_tts_request_payload_speech_model",
    "GetTtsResultsTtsResultsPostResponseValue": ".get_tts_results_tts_results_post_response_value",
    "GetTtsRunInfoTtsResultRunIdGetResponse": ".get_tts_run_info_tts_result_run_id_get_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CreateStreamTtsRequestPayloadLanguage",
    "CreateStreamTtsRequestPayloadSpeechModel",
    "GetTtsResultsTtsResultsPostResponseValue",
    "GetTtsRunInfoTtsResultRunIdGetResponse",
]
