# This file was auto-generated by Fern from our API Definition.

import typing

OutputFormat = typing.Union[
    typing.Literal[
        "wav", "flac", "adts", "mp3", "pcm_s16le", "pcm_s16be", "pcm_s32be", "pcm_s32le", "pcm_f32le", "pcm_f32be"
    ],
    typing.Any,
]
