# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.audio_output_type import AudioOutputType
from ...types.video_output_type_without_avi import VideoOutputTypeWithoutAvi

DubbedOutputInAltFormatRequestPayloadOutputFormat = typing.Union[AudioOutputType, VideoOutputTypeWithoutAvi]
