# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .dubbed_output_in_alt_format_request_payload_output_format import (
        DubbedOutputInAltFormatRequestPayloadOutputFormat,
    )
    from .get_dubbed_output_in_alt_format_dub_alt_format_run_id_language_post_response import (
        GetDubbedOutputInAltFormatDubAltFormatRunIdLanguagePostResponse,
    )
    from .get_dubbed_run_info_dub_result_run_id_get_response import GetDubbedRunInfoDubResultRunIdGetResponse
    from .get_dubbing_runs_results_dubbing_results_post_response_value import (
        GetDubbingRunsResultsDubbingResultsPostResponseValue,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "DubbedOutputInAltFormatRequestPayloadOutputFormat": ".dubbed_output_in_alt_format_request_payload_output_format",
    "GetDubbedOutputInAltFormatDubAltFormatRunIdLanguagePostResponse": ".get_dubbed_output_in_alt_format_dub_alt_format_run_id_language_post_response",
    "GetDubbedRunInfoDubResultRunIdGetResponse": ".get_dubbed_run_info_dub_result_run_id_get_response",
    "GetDubbingRunsResultsDubbingResultsPostResponseValue": ".get_dubbing_runs_results_dubbing_results_post_response_value",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DubbedOutputInAltFormatRequestPayloadOutputFormat",
    "GetDubbedOutputInAltFormatDubAltFormatRunIdLanguagePostResponse",
    "GetDubbedRunInfoDubResultRunIdGetResponse",
    "GetDubbingRunsResultsDubbingResultsPostResponseValue",
]
