# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AudioStream(UniversalBaseModel):
    index: int
    codec_name: str
    codec_long_name: str
    codec_tag_string: typing.Optional[str] = None
    codec_tag: typing.Optional[str] = None
    profile: typing.Optional[str] = None
    sample_fmt: str
    sample_rate: int
    channels: int
    channel_layout: typing.Optional[str] = None
    id: typing.Optional[str] = None
    bit_rate: typing.Optional[int] = None
    tags: typing.Optional[typing.Dict[str, typing.Any]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
