# This file was auto-generated by Fern from our API Definition.

import typing

CreateStreamTtsRequestPayloadLanguage = typing.Union[
    typing.Literal[
        "ar-kw",
        "de-ch",
        "ko-kr",
        "th-th",
        "ml-in",
        "pt-pt",
        "kn-in",
        "fi-fi",
        "es-mx",
        "fr-ca",
        "cs-cz",
        "pt-br",
        "hi-in",
        "ar-sy",
        "es-us",
        "bn-bd",
        "ja-jp",
        "mr-in",
        "ar-ma",
        "es-es",
        "en-us",
        "zh-cn",
        "el-gr",
        "pl-pl",
        "ar-om",
        "fr-ch",
        "en-uk",
        "en-au",
        "ar-jo",
        "ar-ae",
        "tr-tr",
        "ar-ly",
        "ru-ru",
        "en-in",
        "ar-ye",
        "ar-eg",
        "fr-be",
        "ta-in",
        "zh-tw",
        "vi-vn",
        "bn-in",
        "ar-sa",
        "de-at",
        "pa-in",
        "it-it",
        "nl-nl",
        "ar-bh",
        "fr-fr",
        "ar-qa",
        "uk-ua",
        "ar-tn",
        "de-de",
        "ar-xa",
        "ar-lb",
        "zh-hk",
        "ro-ro",
        "as-in",
        "ar-iq",
        "nl-be",
        "te-in",
        "id-id",
        "ar-dz",
    ],
    typing.Any,
]
