# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .orchestrator_pipeline_result_exception_reason import OrchestratorPipelineResultExceptionReason
from .orchestrator_pipeline_result_message import OrchestratorPipelineResultMessage
from .task_status import TaskStatus


class OrchestratorPipelineResult(UniversalBaseModel):
    status: TaskStatus
    run_id: typing.Optional[int] = None
    exception_reason: typing.Optional[OrchestratorPipelineResultExceptionReason] = None
    message: typing.Optional[OrchestratorPipelineResultMessage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
