from enum import Enum


class Languages(int, Enum):
    EN_US = 1
    AF_ZA = 2
    AM_ET = 3
    AR_AE = 4
    AR_BH = 5
    AR_DZ = 6
    AR_EG = 7
    AR_IQ = 8
    AR_JO = 9
    AR_KW = 10
    AR_LB = 11
    AR_LY = 12
    AR_MA = 13
    AR_OM = 14
    AR_QA = 15
    AR_SA = 16
    AR_SY = 17
    AR_TN = 18
    AR_YE = 19
    AZ_AZ = 20
    BG_BG = 21
    BN_BD = 22
    BN_IN = 23
    BS_BA = 24
    CA_ES = 25
    CS_CZ = 26
    CY_GB = 27
    DA_DK = 28
    DE_AT = 29
    DE_CH = 30
    DE_DE = 31
    EL_GR = 32
    EN_AU = 33
    EN_CA = 34
    EN_GB = 35
    EN_HK = 36
    EN_IE = 37
    EN_IN = 38
    EN_KE = 39
    EN_NG = 40
    EN_NZ = 41
    EN_PH = 42
    EN_SG = 43
    EN_TZ = 44
    EN_ZA = 45
    ES_AR = 46
    ES_BO = 47
    ES_CL = 48
    ES_CO = 49
    ES_CR = 50
    ES_CU = 51
    ES_DO = 52
    ES_EC = 53
    ES_ES = 54
    ES_GQ = 55
    ES_GT = 56
    ES_HN = 57
    ES_MX = 58
    ES_NI = 59
    ES_PA = 60
    ES_PE = 61
    ES_PR = 62
    ES_PY = 63
    ES_SV = 64
    ES_US = 65
    ES_UY = 66
    ES_VE = 67
    ET_EE = 68
    EU_ES = 69
    FA_IR = 70
    FI_FI = 71
    FIL_PH = 72
    FR_BE = 73
    FR_CA = 74
    FR_CH = 75
    FR_FR = 76
    GA_IE = 77
    GL_ES = 78
    GU_IN = 79
    HE_IL = 80
    HI_IN = 81
    HR_HR = 82
    HU_HU = 83
    HY_AM = 84
    ID_ID = 85
    IS_IS = 86
    IT_IT = 87
    JA_JP = 88
    JV_ID = 89
    KA_GE = 90
    KK_KZ = 91
    KM_KH = 92
    KN_IN = 93
    KO_KR = 94
    LO_LA = 95
    LT_LT = 96
    LV_LV = 97
    MK_MK = 98
    ML_IN = 99
    MN_MN = 100
    MR_IN = 101
    MS_MY = 102
    MT_MT = 103
    MY_MM = 104
    NB_NO = 105
    NE_NP = 106
    NL_BE = 107
    NL_NL = 108
    PL_PL = 109
    PS_AF = 110
    PT_BR = 111
    PT_PT = 112
    RO_RO = 113
    RU_RU = 114
    SI_LK = 115
    SK_SK = 116
    SL_SI = 117
    SO_SO = 118
    SQ_AL = 119
    SR_RS = 120
    SU_ID = 121
    SV_SE = 122
    SW_KE = 123
    SW_TZ = 124
    TA_IN = 125
    TA_LK = 126
    TA_MY = 127
    TA_SG = 128
    TE_IN = 129
    TH_TH = 130
    TR_TR = 131
    UK_UA = 132
    UR_IN = 133
    UR_PK = 134
    UZ_UZ = 135
    VI_VN = 136
    ZH_CN = 139
    ZH_CN_HENAN = 140
    ZH_CN_LIAONING = 141
    ZH_CN_SHAANXI = 142
    ZH_CN_SHANDONG = 143
    ZH_CN_SICHUAN = 144
    ZH_HK = 145
    ZH_TW = 146
    ZU_ZA = 147
    PA_IN = 148

    SA_IN = 149
    AR_XA = 150
    TL_PH = 151