# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .languages import Languages


class Voice(UniversalBaseModel):
    id: int
    voice_name: str
    gender: typing.Optional[int] = None
    age: typing.Optional[int] = None
    language: typing.Optional[Languages] = None
    transcript: typing.Optional[str] = None
    description: typing.Optional[str] = None
    is_published: typing.Optional[bool] = None
    signed_url: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
