# This file was auto-generated by Fern from our API Definition.

import enum


class CambApiEnvironment(enum.Enum):
    # DEFAULT = "https://knative-dev-client.camb.ai/apis"
    DEFAULT = "https://client.camb.ai/apis"
