# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.orchestrator_pipeline_call_result import OrchestratorPipelineCallResult

GetDubbedOutputInAltFormatDubAltFormatRunIdLanguagePostResponse = typing.Union[
    typing.Dict[str, str], OrchestratorPipelineCallResult
]
