# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .output_format import OutputFormat


class StreamTtsOutputConfiguration(UniversalBaseModel):
    """
    Configuration for the output audio of Streaming TTS.

    Attributes:
        format: The format of the output audio. Defaults to MP3.
        duration: The desired duration of the output audio in seconds. If not
            provided, it will be determined automatically.
        apply_enhancement: Whether to apply audio enhancement to the output.
            Defaults to True.
    """

    format: typing.Optional[OutputFormat] = None
    duration: typing.Optional[float] = None
    apply_enhancement: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
