# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .languages import Languages


class ProjectDetails(UniversalBaseModel):
    project_name: str
    project_description: typing.Optional[str] = None
    created_at: dt.datetime
    source_language: Languages
    target_languages: typing.List[Languages]
    duration: typing.Optional[float] = None
    folder_id: typing.Optional[int] = None
    studio_url: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
