# This file was auto-generated by Fern from our API Definition.

import typing

ExceptionReasons = typing.Union[
    typing.Literal[
        "HARMFUL_CONTENT_DETECTED",
        "VOICE_CONVERSION_ERROR",
        "PROCESSING_ERROR",
        "SOURCE_TOO_LONG",
        "SOURCE_TOO_LARGE",
        "SOURCE_TYPE_NOT_SUPPORTED",
        "ERROR_DOWNLOADING_SOURCE",
        "TOO_MANY_GDRIVE_REQUESTS",
        "SOURCE_BLOCKED_IN_REGION",
        "SOURCE_IS_AGE_RESTRICTED",
        "SOURCE_NOT_FOUND",
        "MISMATCHED_SOURCE_CODEC",
        "CONTENT_DOES_NOT_MATCH_EXTENSION",
        "INVALID_SOURCE_DATA",
        "VIDEO_DOES_NOT_HAVE_AUDIO_STREAMS",
        "MASTERING_OUT_OF_RANGE",
        "INVALID_AUDIO_TRACKS_SELECTION",
        "PAYMENT_REQUIRED",
        "FORBIDDEN",
        "INTERNAL_ERROR",
        "NONE",
    ],
    typing.Any,
]
