# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.dubbing_result import DubbingResult

GetDubbingRunsResultsDubbingResultsPostResponseValue = typing.Union[DubbingResult, typing.Dict[str, DubbingResult]]
