# This file was auto-generated by Fern from our API Definition.

import typing

from .exception_reasons import ExceptionReasons

OrchestratorPipelineResultExceptionReason = typing.Union[str, ExceptionReasons]
