# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.get_setup_story_result_response import GetSetupStoryResultResponse
from ...types.orchestrator_pipeline_call_result import OrchestratorPipelineCallResult

CreateStoryStoryPostResponse = typing.Union[OrchestratorPipelineCallResult, GetSetupStoryResultResponse]
