# This file was auto-generated by Fern from our API Definition.

import typing

DemixingOption = typing.Union[
    typing.Literal[
        "none", "pick_left_channel", "pick_right_channel", "pick_center_channel", "best_model", "fast_model"
    ],
    typing.Any,
]
