# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audio_stream import AudioStream
from .data_stream import DataStream
from .video_stream import VideoStream


class GetProbeStreamOut(UniversalBaseModel):
    video_streams: typing.List[VideoStream]
    audio_streams: typing.List[AudioStream]
    data_streams: typing.List[DataStream]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
