# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.get_tts_result_out_file_url import GetTtsResultOutFileUrl

GetTtsResultsTtsResultsPostResponseValue = typing.Union[str, GetTtsResultOutFileUrl]
