# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from .types.create_story_story_post_response import CreateStoryStoryPostResponse
from .types.setup_story_story_setup_post_response import SetupStoryStorySetupPostResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawStoryClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateStoryStoryPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateStoryStoryPostResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "story",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateStoryStoryPostResponse,
                    parse_obj_as(
                        type_=CreateStoryStoryPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def setup_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SetupStoryStorySetupPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SetupStoryStorySetupPostResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "story-setup",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetupStoryStorySetupPostResponse,
                    parse_obj_as(
                        type_=SetupStoryStorySetupPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"story/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_story_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"story-result/{jsonable_encoder(run_id)}",
            method="GET",
            params={
                "include_transcript": include_transcript,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_stories_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "stories-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Dict[str, typing.Any]],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Dict[str, typing.Any]],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawStoryClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateStoryStoryPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateStoryStoryPostResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "story",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateStoryStoryPostResponse,
                    parse_obj_as(
                        type_=CreateStoryStoryPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def setup_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SetupStoryStorySetupPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SetupStoryStorySetupPostResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "story-setup",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetupStoryStorySetupPostResponse,
                    parse_obj_as(
                        type_=SetupStoryStorySetupPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"story/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_story_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"story-result/{jsonable_encoder(run_id)}",
            method="GET",
            params={
                "include_transcript": include_transcript,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_stories_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "stories-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Dict[str, typing.Any]],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Dict[str, typing.Any]],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
